@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.8"
+    version = "1.8.9"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -127,7 +127,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
-        payload = f"{payload} > 查看详情: <font color=blue>[{group.message[0:30]}]({issue_link})</font> \n\n"
+        payload = f"{payload} > 查看详情: <font color=blue>[{'Error: ' + group.message[0:50]}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > Hi: {event.__dict__} \n\n"
         # payload = f"{payload} > Hi: {event.data} \n\n"
